[Compare the full difference.](https://github.com/callowayproject/bump-my-version/compare/1.2.5...1.2.6)

### Fixes

- Fix: Set default `is_flag` value to `False` in click_config. [6f5d13d](https://github.com/callowayproject/bump-my-version/commit/6f5d13dd01c9f8e53accad72990f3c1cb3f417b8)
    
- Fix Jinja template includes to use `.jinja` file extension consistently. [13b7902](https://github.com/callowayproject/bump-my-version/commit/13b790224ffb2c0aea554f9a1db5741e90cf046f)
    
### New

- Add Python 3.14 to GitHub Actions test matrix. [f8ff078](https://github.com/callowayproject/bump-my-version/commit/f8ff0783a2c82b9345a5de84ba3f92917c0eb35c)
    
### Other

- Bump Click dependency to version 8.3.1 for Python 3.10+. [c9db946](https://github.com/callowayproject/bump-my-version/commit/c9db9461bb7cef398430953d0c6430a442d3f70a)
    
- Bump click support to <8.4. [be429e8](https://github.com/callowayproject/bump-my-version/commit/be429e8e99d492ae375e6480b4f9940ca0b7dc15)
    
  fixes #377
- Bump the github-actions group across 1 directory with 2 updates. [05edf97](https://github.com/callowayproject/bump-my-version/commit/05edf97baa237a6e628eb680179f60f66fa054ce)
    
  Bumps the github-actions group with 2 updates in the / directory: [actions/checkout](https://github.com/actions/checkout) and [actions/download-artifact](https://github.com/actions/download-artifact).


  Updates `actions/checkout` from 5 to 6
  - [Release notes](https://github.com/actions/checkout/releases)
  - [Changelog](https://github.com/actions/checkout/blob/main/CHANGELOG.md)
  - [Commits](https://github.com/actions/checkout/compare/v5...v6)

  Updates `actions/download-artifact` from 6 to 7
  - [Release notes](https://github.com/actions/download-artifact/releases)
  - [Commits](https://github.com/actions/download-artifact/compare/v6...v7)

  ---
  **updated-dependencies:** - dependency-name: actions/checkout
dependency-version: '6'
dependency-type: direct:production
update-type: version-update:semver-major
dependency-group: github-actions

  **signed-off-by:** dependabot[bot] <support@github.com>

- [pre-commit.ci] pre-commit autoupdate. [d2edfae](https://github.com/callowayproject/bump-my-version/commit/d2edfaed09266b4106751d5554418beb934824a1)
    
  **updates:** - [github.com/astral-sh/ruff-pre-commit: v0.14.6 → v0.14.10](https://github.com/astral-sh/ruff-pre-commit/compare/v0.14.6...v0.14.10)
